DROP TABLE IF EXISTS Tiene;

DROP TABLE IF EXISTS Pide;

DROP TABLE IF EXISTS Efectua;

DROP TABLE IF EXISTS Realiza;

DROP TABLE IF EXISTS Familiar;

DROP TABLE IF EXISTS Ingreso;

DROP TABLE IF EXISTS Egreso;

DROP TABLE IF EXISTS Reposo;

DROP TABLE IF EXISTS Cambio_salario;

DROP TABLE IF EXISTS Organizacion;

DROP TABLE IF EXISTS Trabajador;

CREATE TABLE `Trabajador`(
  cedula VARCHAR(10) NOT NULL,
  nombres VARCHAR(50) NOT NULL,
  apellidos VARCHAR(50) NOT NULL,
  nacionalidad VARCHAR(20) NOT NULL,
  sexo CHAR
    CHECK (sexo IN ('M', 'F')),
  fe_nacimiento DATE NOT NULL,
  salario REAL NOT NULL,
  direccion VARCHAR(500),
  telefono VARCHAR(12),
  estado CHAR
<<<<<<< Updated upstream
    CHECK (estado IN ('I','E','R')),
   /*
    I = Ingresado.
    E = Egresado.
		R = Reposo.
=======
    CHECK (estado IN ('I','E')),
   /*
    I = Ingresado.
    E = Egresado.
>>>>>>> Stashed changes
  */

  PRIMARY KEY(cedula)
);

CREATE TABLE `Organizacion`(
  cod_organizacion INT NOT NULL AUTO_INCREMENT,
  nom_organizacion VARCHAR(50) NOT NULL,
  desc_organizacion VARCHAR(500) NOT NULL,

  PRIMARY KEY(cod_organizacion)
);

CREATE TABLE `Cambio_salario`(
  cod_cambio_salario INT NOT NULL,
  fe_cambio_salario DATE NOT NULL,
  motivo VARCHAR(500) NOT NULL,
  nuevo_salario REAL NOT NULL,
  viejo_salario REAL NOT NULL,
  estado VARCHAR(2)
    CHECK (estado IN ('CP', 'NP', 'EP')),
  /*
    CP = Cambio Procesado.
    NP = No procesado o no enviado.
    EP = En Proceso.
  */

  PRIMARY KEY(cod_cambio_salario)
);

CREATE TABLE `Familiar`(
  cedula_fam VARCHAR(10) NOT NULL,
  trabajador_cedula VARCHAR(10) NOT NULL,
  nombres VARCHAR(50) NOT NULL,
  apellidos VARCHAR(50) NOT NULL,
  parentesco VARCHAR(20) NOT NULL,
  fe_nacimiento DATE NOT NULL,
  sexo CHAR
    CHECK (sexo IN ('M', 'F')),

  PRIMARY KEY(cedula_fam, trabajador_cedula)
);

CREATE TABLE `Reposo`(
  cod_reposo INT NOT NULL AUTO_INCREMENT,
  motivo VARCHAR(500) NOT NULL,
  patologia VARCHAR(500) NOT NULL,
  fe_inicio DATE NOT NULL,
  fe_finalizacion DATE NOT NULL,
  estado VARCHAR(2)
    CHECK (estado IN ('CP', 'NP', 'EP')),

  /*
    CP = Cambio Procesado.
    NP = No procesado o no enviado.
    EP = En Proceso.
  */

  PRIMARY KEY(cod_reposo)
);

CREATE TABLE `Egreso`(
  cod_egreso INT NOT NULL AUTO_INCREMENT,
  fe_egreso DATE NOT NULL,
  motivo VARCHAR(500) NOT NULL,

  PRIMARY KEY(cod_egreso)
);

CREATE TABLE `Ingreso`(
  cod_ingreso INT NOT NULL AUTO_INCREMENT,
  fe_ingreso DATE NOT NULL,

  PRIMARY KEY(cod_ingreso)
);

CREATE TABLE Realiza(
  `cod_ingreso` INT NOT NULL,
  `trabajador_cedula` VARCHAR(10) NOT NULL,
  `cod_organizacion` INT NOT NULL,
  fe_revision_organizacion DATE NOT NULL,
  estatus_revision VARCHAR(2)
    CHECK (estatus_revision IN ('ER', 'RC', 'SR')),
  /*
    ER: En revision.
    RC: Revision completa.
    SR: Sin revisar.
  */
 PRIMARY KEY(cod_ingreso, trabajador_cedula, cod_organizacion)
);

CREATE TABLE Efectua(
  `cod_egreso` INT NOT NULL,
  `trabajador_cedula` VARCHAR(10) NOT NULL,
  `cod_organizacion` INT NOT NULL,
  fe_revision_organizacion DATE NOT NULL,
  estatus_revision VARCHAR(2)
    CHECK (estatus_revision IN ('ER', 'RC', 'SR')),
    /*
      ER: En revision.
      RC: Revision completa.
      SR: Sin revisar.
    */
   KEY(cod_egreso, trabajador_cedula, cod_organizacion)
);

CREATE TABLE Pide(
  `cod_cambio_salario` INT NOT NULL,
  `trabajador_cedula` VARCHAR(10) NOT NULL,
  `cod_organizacion` INT NOT NULL,
  fe_revision_organizacion DATE NOT NULL,
  estatus_revision VARCHAR(2)
    CHECK (estatus_revision IN ('ER', 'RC', 'SR')),
    /*
      ER: En revision.
      RC: Revision completa.
      SR: Sin revisar.
    */
  PRIMARY KEY(cod_cambio_salario, trabajador_cedula, cod_organizacion)
);

CREATE TABLE Tiene(
  `cod_reposo` INT NOT NULL,
  `trabajador_cedula` VARCHAR(10) NOT NULL,
  `cod_organizacion` INT NOT NULL,
  fe_revision_organizacion DATE NOT NULL,
  estatus_revision VARCHAR(2)
    CHECK (estatus_revision IN ('ER', 'RC', 'SR')),
    /*
      ER: En revision.
      RC: Revision completa.
      SR: Sin revisar.
    */
  PRIMARY KEY(cod_reposo, trabajador_cedula, cod_organizacion)
);

ALTER TABLE Realiza
  ADD CONSTRAINT `Trabajador_realiza`
    FOREIGN KEY (`trabajador_cedula`) REFERENCES `Trabajador` (cedula);

ALTER TABLE Realiza
  ADD CONSTRAINT `Organizacion_realiza`
    FOREIGN KEY (`cod_organizacion`) REFERENCES `Organizacion` (cod_organizacion);

ALTER TABLE Realiza
  ADD CONSTRAINT `Ingreso_realiza`
    FOREIGN KEY (`cod_ingreso`) REFERENCES `Ingreso` (cod_ingreso);

ALTER TABLE Efectua
  ADD CONSTRAINT `Egreso_efectua`
    FOREIGN KEY (`cod_egreso`) REFERENCES `Egreso` (cod_egreso);

ALTER TABLE Efectua
  ADD CONSTRAINT `Trabajador_efectua`
    FOREIGN KEY (`trabajador_cedula`) REFERENCES `Trabajador` (cedula);

ALTER TABLE Efectua
  ADD CONSTRAINT `Organizacion_efectua`
    FOREIGN KEY (`cod_organizacion`) REFERENCES `Organizacion` (cod_organizacion);

ALTER TABLE Pide
  ADD CONSTRAINT `Trabajador_pide`
    FOREIGN KEY (`trabajador_cedula`) REFERENCES `Trabajador` (cedula);

ALTER TABLE Pide
  ADD CONSTRAINT `Organizacion_pide`
    FOREIGN KEY (`cod_organizacion`) REFERENCES `Organizacion` (cod_organizacion);

ALTER TABLE Pide
  ADD CONSTRAINT `Cambio_salario_pide`
    FOREIGN KEY (`cod_cambio_salario`) REFERENCES `Cambio_salario` (cod_cambio_salario);

ALTER TABLE Tiene
  ADD CONSTRAINT `Trabajador_tiene`
    FOREIGN KEY (`trabajador_cedula`) REFERENCES `Trabajador` (cedula);

ALTER TABLE Tiene
  ADD CONSTRAINT `Organizacion_tiene`
    FOREIGN KEY (`cod_organizacion`) REFERENCES `Organizacion` (cod_organizacion);

ALTER TABLE Tiene
  ADD CONSTRAINT `Reposo_tiene`
    FOREIGN KEY (`cod_reposo`) REFERENCES `Reposo` (cod_reposo);

ALTER TABLE `Familiar`
  ADD CONSTRAINT `Familiar_Trabajadores`
    FOREIGN KEY (`trabajador_cedula`) REFERENCES `Trabajador` (cedula);
